<?php

namespace App\Controllers;

use Sober\Controller\Controller;

class App extends Controller
{
    protected $acf = true;

    public function siteName()
    {
        return get_bloginfo('name');
    }

    public static function title()
    {
        if (is_home()) {
            if ($home = get_option('page_for_posts', true)) {
                return get_the_title($home);
            }
            return __('Latest Posts', 'sage');
        }
        if (is_archive()) {
            if (get_post_type()=='repairs_list' || get_post_type()=='blog') {
                return sprintf(__('%s'), post_type_archive_title('', false));
            } else {
                return get_the_archive_title();
            }
        }
        if (is_search()) {
            return sprintf(__('Search Results for %s', 'sage'), get_search_query());
        }
        if (is_404()) {
            return __('Not Found', 'sage');
        }
        return get_the_title();
    }

    public static function repair_list_header()
    {
        $logo = '';
        if (have_rows('theme_options', 'option')) {
            while (have_rows('theme_options', 'option')) {
                the_row();
                $logo = get_sub_field('repair_list_header');
            }
            return $logo['url'];
        }
        return \App\asset_path('images/inner-banner.jpg');
    }

    public static function get_seo_image($image_id, $size, $classes)
    {
        if( !empty($image_id) && is_array($image_id) ):
            $responsive_image_markup = wp_get_attachment_image($image_id['id'], $size, false, array( 'class' => $classes ));
        else:
            $responsive_image_markup = '';
        endif;
        echo apply_filters('the_content', $responsive_image_markup);
    }

    public static function clean($string)
    {
        $string = strtolower(str_replace(' ', '-', $string)); // Replaces all spaces with hyphens.

        return preg_replace('/[^A-Za-z\-]/', '', $string); // Removes special chars.
    }

//    /**
//     * @return false|mixed|string
//     */
//    public function site_logo()
//    {
//        $logo = '';
//        if (have_rows('theme_options', 'option')) {
//            while (have_rows('theme_options', 'option')) {
//                the_row();
//                $logo = get_sub_field('logo') ? get_sub_field('logo') : asset_path('images/logo.svg') ;
//            }
//
//            return $logo;
//        }
//        return $logo;
//    }
}
