<?php

namespace App;

use Roots\Sage\Container;
use Roots\Sage\Assets\JsonManifest;
use Roots\Sage\Template\Blade;
use Roots\Sage\Template\BladeProvider;
use WP_Error;

/**
 * Theme assets
 */
add_action('wp_enqueue_scripts', function () {

    //Main Scripts - JS and CSS
    wp_enqueue_style('sage/main.css', asset_path('styles/main.css'), false, null);
    wp_enqueue_script('sage/main.js', asset_path('scripts/main.js'), ['jquery'], null, true);
    wp_enqueue_script('bootstrap', get_template_directory_uri() . '/assets/scripts/original/bootstrap.bundle.min.js', ['jquery'], null, true);

    // Load custom js for inner pages
    wp_enqueue_script('inner-custom', get_template_directory_uri() . '/assets/scripts/original/custom-js.js', ['jquery'], null, true);

    // Owl - JS and CSS
    wp_register_script('owl-carousel', get_template_directory_uri() . '/assets/scripts/original/owl.carousel.min.js', ['jquery'], null, true);
    wp_register_style('owl', get_template_directory_uri() . '/assets/styles/owl.carousel.min.css', false, null);
    wp_register_style('owl-theme', get_template_directory_uri() . '/assets/styles/owl.theme.default.min.css', false, null);

    // Customer Experience CSS
    wp_register_style('customer-experience', get_template_directory_uri() . '/assets/styles/customer-experience-style.css', false, null);
    
    // Software Development js & CSS
    wp_register_script('software-development-script', get_template_directory_uri() . '/assets/scripts/software-development-script.js', ['jquery'], null, true);
    wp_register_style('software-development', get_template_directory_uri() . '/assets/styles/software-development-style.css', false, null);
    
    // App & Technical Support js & CSS
    wp_register_script('app-technical-script', get_template_directory_uri() . '/assets/scripts/app-technical-script.js', ['jquery'], null, true);
    wp_register_style('app-technical', get_template_directory_uri() . '/assets/styles/app-technical-style.css', false, null);

    // Particles lib JS
    wp_register_script('particles', get_template_directory_uri() . '/assets/scripts/original/particles.min.js', ['jquery'], null, true);

    if (is_single() && comments_open() && get_option('thread_comments')) {
        wp_enqueue_script('comment-reply');
    }
}, 100);

/**
 * Theme setup
 */
add_action('after_setup_theme', function () {
    /**
     * Enable features from Soil when plugin is activated
     * @link https://roots.io/plugins/soil/
     */
    add_theme_support('soil-clean-up');
    add_theme_support('soil-jquery-cdn');
    add_theme_support('soil-nav-walker');
    add_theme_support('soil-nice-search');
    add_theme_support('soil-relative-urls');

    /**
     * Enable plugins to manage the document title
     * @link https://developer.wordpress.org/reference/functions/add_theme_support/#title-tag
     */
    add_theme_support('title-tag');

    /**
     * Register navigation menus
     * @link https://developer.wordpress.org/reference/functions/register_nav_menus/
     */
    register_nav_menus([
        'primary_navigation' => __('Primary Navigation', 'sage'),'secondary_navigation' => __('Secondary Navigation', 'sage')
    ]);

    /**
     * Enable post thumbnails
     * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
     */
    add_theme_support('post-thumbnails');

    /**
     * Enable HTML5 markup support
     * @link https://developer.wordpress.org/reference/functions/add_theme_support/#html5
     */
    add_theme_support('html5', ['caption', 'comment-form', 'comment-list', 'gallery', 'search-form']);

    /**
     * Enable selective refresh for widgets in customizer
     * @link https://developer.wordpress.org/themes/advanced-topics/customizer-api/#theme-support-in-sidebars
     */
    add_theme_support('customize-selective-refresh-widgets');

    /**
     * Use main stylesheet for visual editor
     * @see resources/assets/styles/layouts/_tinymce.scss
     */
    add_editor_style(asset_path('styles/main.css'));
}, 20);

/**
 * Register sidebars
 */
add_action('widgets_init', function () {
    $config = [
        'before_widget' => '<section class="widget %1$s %2$s">',
        'after_widget'  => '</section>',
        'before_title'  => '<h3>',
        'after_title'   => '</h3>'
    ];
    register_sidebar([
            'name'          => __('Primary', 'sage'),
            'id'            => 'sidebar-primary'
        ] + $config);
    register_sidebar([
            'before_widget' => '<section class="widget %1$s %2$s col-xl-4 col-lg-12 col-sm-12">',
            'after_widget'  => '</section>',
            'name'          => __('Footer', 'sage'),
            'id'            => 'sidebar-footer'
        ] + $config);
});

/**
 * Updates the `$post` variable on each iteration of the loop.
 * Note: updated value is only available for subsequently loaded views, such as partials
 */
add_action('the_post', function ($post) {
    sage('blade')->share('post', $post);
});

/**
 * Setup Sage options
 */
add_action('after_setup_theme', function () {
    /**
     * Add JsonManifest to Sage container
     */
    sage()->singleton('sage.assets', function () {
        return new JsonManifest(config('assets.manifest'), config('assets.uri'));
    });

    /**
     * Add Blade to Sage container
     */
    sage()->singleton('sage.blade', function (Container $app) {
        $cachePath = config('view.compiled');
        if (!file_exists($cachePath)) {
            wp_mkdir_p($cachePath);
        }
        (new BladeProvider($app))->register();
        return new Blade($app['view']);
    });

    /**
     * Create @asset() Blade directive
     */
    sage('blade')->compiler()->directive('asset', function ($asset) {
        return "<?= " . __NAMESPACE__ . "\\asset_path({$asset}); ?>";
    });
});
add_filter( 'wpcf7_load_js', '__return_false' );
add_filter('wpcf7_validate_email*', function ($result, $tag) {
    if ('your-email-confirm' == $tag->name) {
        $your_email = isset($_POST['your-email']) ? trim($_POST['your-email']) : '';
        $your_email_confirm = isset($_POST['your-email-confirm']) ? trim($_POST['your-email-confirm']) : '';

        if ($your_email != $your_email_confirm) {
            $result->invalidate($tag, "Are you sure this is the correct address?");
        }
    }

    return $result;
}, 20, 2);

function the_breadcrumb()
{
    $showOnHome = 1; // 1 - show breadcrumbs on the homepage, 0 - don't show
    // $delimiter = '&gt;'; // delimiter between crumbs
    $delimiter = ' '; // delimiter between crumbs
    $home = __('Home', 'axsera'); // text for the 'Home' link
    $blog = __('News', 'axsera');
    ; // text for the 'Home' link
    $showCurrent = 1; // 1 - show current post/page title in breadcrumbs, 0 - don't show
    $before = '<span class="current">'; // tag before the current crumb
    $after = '</span>'; // tag after the current crumb

    global $post;
    $homeLink = get_bloginfo('url');
    //if (is_home() || is_front_page()) {
    if (is_home()) {
        if ($showOnHome == 1) {
            echo '<div id="crumbs"><a href="' . $homeLink . '">' . $home . '</a> '.$delimiter. ' ' . $blog . '</a></div>';
        }
    } else {
        echo '<div id="crumbs"><a href="' . $homeLink . '">' . $home . '</a> ' . $delimiter . ' ';
        if (is_category()) {
            $thisCat = get_category(get_query_var('cat'), false);
            if ($thisCat->parent != 0) {
                echo get_category_parents($thisCat->parent, true, ' ' . $delimiter . ' ');
            }
            echo $before . __('Archive by category "', 'axsera') . single_cat_title('', false) . '"' . $after;
        } elseif (is_search()) {
            echo $before . __('Search results for "', 'axsera') . get_search_query() . '"' . $after;
        } elseif (is_day()) {
            echo '<a href="' . get_year_link(get_the_time('Y')) . '">' . get_the_time('Y') . '</a> ' . $delimiter . ' ';
            echo '<a href="' . get_month_link(get_the_time('Y'), get_the_time('m')) . '">' . get_the_time('F') . '</a> ' . $delimiter . ' ';
            echo $before . get_the_time('d') . $after;
        } elseif (is_month()) {
            echo '<a href="' . get_year_link(get_the_time('Y')) . '">' . get_the_time('Y') . '</a> ' . $delimiter . ' ';
            echo $before . get_the_time('F') . $after;
        } elseif (is_year()) {
            echo $before . get_the_time('Y') . $after;
        } elseif (is_single() && !is_attachment()) {
            if (get_post_type() != 'post') {
                $post_type = get_post_type_object(get_post_type());
                $slug = $post_type->rewrite;
                echo '<a href="' . $homeLink . '/' . $slug['slug'] . '/">' . $post_type->labels->singular_name . '</a>';
                if ($showCurrent == 1) {
                    echo ' ' . $delimiter . ' ' . $before . get_the_title() . $after;
                }
            } else {
                $cat = get_the_category();
                $cat = $cat[0];
                $cats = get_category_parents($cat, true, ' ' . $delimiter . ' ');
                if ($showCurrent == 0) {
                    $cats = preg_replace("#^(.+)\s$delimiter\s$#", "$1", $cats);
                }
                echo $cats;
                if ($showCurrent == 1) {
                    echo $before . get_the_title() . $after;
                }
            }
        } elseif (!is_single() && !is_page() && get_post_type() != 'post' && !get_post_type() != 'agents' && !is_404()) {
            $post_type = get_post_type_object(get_post_type());
            echo $before . $post_type->labels->singular_name . $after;
        } elseif (is_attachment()) {
            $parent = get_post($post->post_parent);
            $cat = get_the_category($parent->ID);
            $cat = $cat[0];
            echo get_category_parents($cat, true, ' ' . $delimiter . ' ');
            echo '<a href="' . get_permalink($parent) . '">' . $parent->post_title . '</a>';
            if ($showCurrent == 1) {
                echo ' ' . $delimiter . ' ' . $before . get_the_title() . $after;
            }
        } elseif (is_page() && !$post->post_parent) {
            if ($showCurrent == 1) {
                echo $before . get_the_title() . $after;
            }
        } elseif (is_page() && $post->post_parent) {
            $parent_id  = $post->post_parent;
            $breadcrumbs = array();
            while ($parent_id) {
                $page = get_page($parent_id);
                $breadcrumbs[] = '<a href="' . get_permalink($page->ID) . '">' . get_the_title($page->ID) . '</a>';
                $parent_id  = $page->post_parent;
            }
            $breadcrumbs = array_reverse($breadcrumbs);
            for ($i = 0; $i < count($breadcrumbs); $i++) {
                echo $breadcrumbs[$i];
                if ($i != count($breadcrumbs)-1) {
                    echo ' ' . $delimiter . ' ';
                }
            }
            if ($showCurrent == 1) {
                echo ' ' . $delimiter . ' ' . $before . get_the_title() . $after;
            }
        } elseif (is_tag()) {
            echo $before . __('Posts tagged "', 'axsera') . single_tag_title('', false) . '"' . $after;
        } elseif (is_author()) {
            global $author;
            $userdata = get_userdata($author);
            echo $before . __('Articles posted by ', 'axsera') . $userdata->display_name . $after;
        } elseif (is_404()) {
            echo $before . 'Error 404' . $after;
        }
        if (get_query_var('paged')) {
            if (is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author()) {
                echo ' (';
            }
            echo __('Page', 'axsera') . ' ' . get_query_var('paged');
            if (is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author()) {
                echo ')';
            }
        }
        echo '</div>';
    }
}



add_shortcode('wpb_childpages', function () {
    return wp_get_menu_array('primary_navigation');
});



function filterRepairsList()
{

    $search = $_POST['search'];
    $category = $_POST['category'];

    global $sitepress;

    $args = array(
        'posts_per_page'    => -1,
        'post_type'     => 'repairs_list',
        's' => $search,

    );
    if (!empty($category)) {
        $args['tax_query'] =  array(
            array(
                'taxonomy' => 'categories',
                'field'    => 'slug',
                'terms'    => strtolower($category),
            ),
        );
    }


    $repairs_list = new \WP_Query($args);


    //print_r($repairs_list);die();
    $list = array();
    $cats = array();

    $i = 0;
    while ($repairs_list->have_posts()) {
        $repairs_list->the_post();

        $list [$i]['id'] = get_the_ID();
        $list [$i]['title'] = get_the_title();
        $list [$i]['description'] = get_the_content();
        $list [$i]['category'] = wp_get_object_terms(get_the_ID(), 'categories')[0]->name;
        $cats[$i] = $list [$i]['category'];
        $i++;
    }

    $cats = array_unique($cats);
    //die();


    $h=0;
    foreach ($cats as $cat) {
        ?>
        <div class="card">
            <div class="card-header" id="heading<?=$h?>">
                <h2 class="mb-0">
                    <button class="btn btn-link" type="button" data-toggle="collapse" data-target="#collapse<?=$h?>" aria-expanded="false" aria-controls="collapse<?=$h?>">
                        <i class="fas fa-angle-right"></i><?=$cat;?>
                    </button>
                </h2>
            </div>
            <div id="collapse<?=$h?>" class="collapse" aria-labelledby="heading<?=$h?>" data-parent="#accordionExample">
                <div class="card-body">
                    <table>
                        <tr>
                            <th><?php  _e('Description', 'axsera'); ?></th>
                            <th><?php  _e('Part Number', 'axsera'); ?></th>
                        </tr>
                        <?php
                        foreach ($list as $item) :
                            if ($item['category'] == $cat) :
                                ?>
                                <tr>
                                    <td>
                                        <?=$item['description']?>
                                    </td>
                                    <td>
                                        <?=$item['title']?>
                                    </td>
                                </tr>
                            <?php else :
                                continue;
                            endif;
                        endforeach;?>
                    </table>

                </div>
            </div>
        </div>
        <?php $h++;
    }
    wp_die();
}

function wp_get_menu_array($current_menu)
{

    //$array_menu = wp_get_nav_menu_items($current_menu);
    $menu_name = $current_menu;

    if (( $locations = get_nav_menu_locations() ) && isset($locations[ $menu_name ])) {
        global $post;
        $menu = wp_get_nav_menu_object($locations[ $menu_name ]);
        $menu_items = wp_get_nav_menu_items($menu->term_id);
        $menu_list = '<ul class="blog-cat">' . "\n";
        $menu_list .= '<li><a href="' . get_permalink($post->post_parent) . '">' . get_the_title($post->post_parent) . '</a></li>' . "\n";

        foreach ((array) $menu_items as $key => $menu_item) {
            if ($post->post_parent == $menu_item->post_parent) {
                $title = $menu_item->title;
                $url = $menu_item->url;

                if ($menu_item->object_id == get_the_ID()) {
                    $menu_list .= '<li class="page_item current_page_item"><a href="' . $url . '">' . $title .  '</a></li>';
                } else {
                    $menu_list .= '<li><a href="' . $url . '">' . $title . '</a></li>';
                }
            }
            //var_dump($menu_item);
        }
        $menu_list .= '</ul>';
    } else {
        $menu_list = '<ul><li>Menu "' . $menu_name . '" not defined.</li></ul>';
    }
    return $menu_list;
}

// Disable Rest API for non logged in users
add_filter('rest_authentication_errors', __NAMESPACE__. '\\disable_rest');

function disable_rest($result)
{
    // If a previous authentication check was applied,
    // pass that result along without modification.
    if (true === $result || is_wp_error($result)) {
        return $result;
    }

    // No authentication has been performed yet.
    // Return an error if user is not logged in.
    if (! is_user_logged_in()) {
        return new WP_Error(
            'rest_not_logged_in',
            __('You are not currently logged in.'),
            array( 'status' => 401 )
        );
    }

    // Our custom authentication check should have no effect
    // on logged-in requests
    return $result;
}

add_action('after_setup_theme', function () {
    load_theme_textdomain('sage', get_template_directory() . '/lang');
    load_theme_textdomain('axsera', get_template_directory() . '/lang');
});
